README.md

```bash
$ tctl config: Initialize, authorize, and configure the tctl tool.
$ tctl version: Display version
$ tctl info: Display current tctl tool environment details.
```

```bash
$ tctl [components] [command] [options]
```
